@@ -1,4 +1,4 @@
-/* $Id: dispatcher.c 2155 2009-07-11 14:52:04Z dreibh $
+/* $Id: dispatcher.c 2459 2011-02-01 07:20:56Z dreibh $
  * --------------------------------------------------------------------------
  *
  *              //===//   //=====   //===//   //       //   //===//
@@ -9,7 +9,7 @@
  *
  * ------------- An Efficient RSerPool Prototype Implementation -------------
  *
- * Copyright (C) 2002-2009 by Thomas Dreibholz
+ * Copyright (C) 2002-2011 by Thomas Dreibholz
  *
  * Acknowledgements:
  * Realized in co-operation between Siemens AG and
@@ -306,10 +306,6 @@ void dispatcherEventLoop(struct Dispatcher* dispatcher)
                                  (struct pollfd*)&ufds, &nfds, &timeout,
                                  &pollTimeStamp);
       result = ext_poll((struct pollfd*)&ufds, nfds, timeout);
-      if(result < 0) {
-         logerror("poll() failed");
-         exit(1);
-      }
       dispatcherHandlePollResult(dispatcher, result,
                                  (struct pollfd*)&ufds, nfds, timeout,
                                  pollTimeStamp);
