@@ -1,4 +1,4 @@
-/* $Id: netutilities.c 2409 2011-01-01 20:38:28Z dreibh $
+/* $Id: netutilities.c 2589 2011-08-26 11:21:10Z dreibh $
  * --------------------------------------------------------------------------
  *
  *              //===//   //=====   //===//   //       //   //===//
@@ -868,42 +868,47 @@ void fputaddress(const struct sockaddr* address, const bool port, FILE* fd)
 /* ###### Get IPv4 address scope ######################################### */
 static unsigned int getScopeIPv4(const uint32_t* address)
 {
-    uint32_t a;
-    uint8_t  b1;
-    uint8_t  b2;
+   uint32_t a;
+   uint8_t  b1;
+   uint8_t  b2;
 
-    /* Unspecified */
-    if(*address == 0x00000000) {
-       return(0);
-    }
+   /* Unspecified */
+   if(*address == 0x00000000) {
+      return(0);
+   }
 
-    /* Loopback */
-    a = ntohl(*address);
-    if((a & 0x7f000000) == 0x7f000000) {
-       return(2);
-    }
+   /* Loopback */
+   a = ntohl(*address);
+   if((a & 0x7f000000) == 0x7f000000) {
+      return(2);
+   }
 
-    /* Class A private */
-    b1 = (uint8_t)(a >> 24);
-    if(b1 == 10) {
-       return(AS_UNICAST_SITELOCAL);
-    }
+   /* Class A private */
+   b1 = (uint8_t)(a >> 24);
+   if(b1 == 10) {
+      return(AS_UNICAST_SITELOCAL);
+   }
 
-    /* Class B private */
-    b2 = (uint8_t)((a >> 16) & 0x00ff);
-    if((b1 == 172) && (b2 >= 16) && (b2 <= 31)) {
-       return(AS_UNICAST_SITELOCAL);
-    }
+   /* Class B private */
+   b2 = (uint8_t)((a >> 16) & 0x00ff);
+   if((b1 == 172) && (b2 >= 16) && (b2 <= 31)) {
+      return(AS_UNICAST_SITELOCAL);
+   }
 
-    /* Class C private */
-    if((b1 == 192) && (b2 == 168)) {
-       return(AS_UNICAST_SITELOCAL);
-    }
+   /* 169.254.0.0/16 link-local [RFC 3927] */
+   if((b1 == 169) && (b2 == 254)) {
+      return(AS_UNICAST_LINKLOCAL);
+   }
 
-    if(IN_MULTICAST(ntohl(*address))) {
-       return(AS_MULTICAST_GLOBAL);
-    }
-    return(AS_UNICAST_GLOBAL);
+   /* Class C private */
+   if((b1 == 192) && (b2 == 168)) {
+      return(AS_UNICAST_SITELOCAL);
+   }
+
+   if(IN_MULTICAST(ntohl(*address))) {
+      return(AS_MULTICAST_GLOBAL);
+   }
+   return(AS_UNICAST_GLOBAL);
 }
 
 
@@ -1574,9 +1579,11 @@ int recvfromplus(int                      sockfd,
          errno = EWOULDBLOCK;
       }
       else {   /* Error */
-         LOG_ERROR
-         fprintf(stdlog, "poll(%d) failed: %s\n", sockfd, strerror(errno));
-         LOG_END
+         if(errno != EINTR) {
+            LOG_ERROR 
+            fprintf(stdlog, "poll(%d) failed: %s\n", sockfd, strerror(errno));
+            LOG_END
+         }
          cc = -1;
       }
    }
@@ -2090,6 +2097,10 @@ int sendabort(int sockfd, sctp_assoc_t assocID)
 /* ###### Send SCTP SHUTDOWN ############################################# */
 int sendshutdown(int sockfd, sctp_assoc_t assocID)
 {
+   if(assocID == 0) {
+      /* FreeBSD seems to ignore SCTP_EOF on TCP-like socket! */
+      return(ext_shutdown(sockfd, 2));
+   }
 #ifdef SOLARIS
    /* The Solaris API has no SCTP_ABORT. Instead, it is a regular flag. */
    return(sendtoplus(sockfd, NULL, 0,
@@ -2160,18 +2171,22 @@ bool tuneSCTP(const int                  sockfd,
    rtoinfo.srto_assoc_id = assocID;
    if(ext_getsockopt(sockfd, IPPROTO_SCTP, SCTP_RTOINFO, &rtoinfo, &size) < 0) {
       LOG_WARNING
-      logerror("getsockopt SCTP_RTOINFO failed -> skipping RTO configuration");
+      logerror("getsockopt SCTP_RTOINFO failed -> skipping assoc configuration");
       LOG_END
       return(false);
    }
    size = (socklen_t)sizeof(peerParams);
    peerParams.spp_assoc_id = assocID;
    memset(&peerParams.spp_address, 0, sizeof(peerParams.spp_address));   // ANY address
+   peerParams.spp_address.ss_family = AF_INET6;
    if(ext_getsockopt(sockfd, IPPROTO_SCTP, SCTP_PEER_ADDR_PARAMS, &peerParams, &size) < 0) {
-      LOG_WARNING
-      logerror("getsockopt SCTP_PEER_ADDR_PARAMS failed -> skipping path configuration");
-      LOG_END
-      return(false);
+      peerParams.spp_address.ss_family = AF_INET;
+      if(ext_getsockopt(sockfd, IPPROTO_SCTP, SCTP_PEER_ADDR_PARAMS, &peerParams, &size) < 0) {
+         LOG_WARNING
+         logerror("getsockopt SCTP_PEER_ADDR_PARAMS failed -> skipping assoc configuration");
+         LOG_END
+         return(false);
+      }
    }
    size = (socklen_t)sizeof(assocParams);
    assocParams.sasoc_assoc_id = assocID;
@@ -2219,15 +2234,12 @@ bool tuneSCTP(const int                  sockfd,
       LOG_END
       result = false;
    }
-
    if(ext_setsockopt(sockfd, IPPROTO_SCTP, SCTP_RTOINFO, &rtoinfo, (socklen_t)sizeof(rtoinfo)) < 0) {
       LOG_WARNING
       logerror("setsockopt SCTP_RTOINFO failed");
       LOG_END
       result = false;
    }
-   peerParams.spp_assoc_id = assocID;
-   memset(&peerParams.spp_address, 0, sizeof(peerParams.spp_address));   // ANY address
    if(ext_setsockopt(sockfd, IPPROTO_SCTP, SCTP_PEER_ADDR_PARAMS, &peerParams, sizeof(peerParams)) < 0) {
       LOG_WARNING
       logerror("setsockopt SCTP_PEER_ADDR_PARAMS failed");
