@@ -1,4 +1,4 @@
-/* $Id: netutilities.h 2210 2009-09-12 07:49:43Z dreibh $
+/* $Id: netutilities.h 2409 2011-01-01 20:38:28Z dreibh $
  * --------------------------------------------------------------------------
  *
  *              //===//   //=====   //===//   //       //   //===//
@@ -9,7 +9,7 @@
  *
  * ------------- An Efficient RSerPool Prototype Implementation -------------
  *
- * Copyright (C) 2002-2009 by Thomas Dreibholz
+ * Copyright (C) 2002-2011 by Thomas Dreibholz
  *
  * Acknowledgements:
  * Realized in co-operation between Siemens AG and
@@ -255,7 +255,7 @@ const struct sockaddr* getBestScopedAddress(const struct sockaddr* addrs,
 size_t filterAddressesByScope(union sockaddr_union* addressArray,
                               const size_t          inputAddresses,
                               const unsigned int    minScope);
-                              
+
 
 /**
   * Get padding for given data size and alignment.
@@ -500,6 +500,29 @@ int ext_poll(struct pollfd* fdlist, long unsigned int count, int time);
 #endif
 
 
+struct TuneSCTPParameters
+{
+   unsigned int InitialRTO;
+   unsigned int MinRTO;
+   unsigned int MaxRTO;
+   unsigned int AssocMaxRxt;
+   unsigned int PathMaxRxt;
+   unsigned int HeartbeatInterval;
+};
+
+/**
+  * Tune parameters of an SCTP association.
+  *
+  * @param fd Socket FD.
+  * @param assocID Association ID.
+  * @param parameters Pointer to TuneSCTPParameters structure with corresponding parameters.
+  * @return true in case of success.
+  */
+bool tuneSCTP(const int                  sockfd,
+              sctp_assoc_t               assocID,
+              struct TuneSCTPParameters* parameters);
+
+
 #ifdef __cplusplus
 }
 #endif
