@@ -1,4 +1,4 @@
-/* $Id: scriptingclient.c 2522 2011-02-19 10:07:13Z dreibh $
+/* $Id: scriptingclient.c 2601 2011-10-28 13:31:42Z dreibh $
  * --------------------------------------------------------------------------
  *
  *              //===//   //=====   //===//   //       //   //===//
@@ -251,10 +251,10 @@ static void handleNotReadyMessage(const int              sd,
                                   const struct NotReady* notReady,
                                   const size_t           length)
 {
-   if(length >= sizeof(struct NotReady)) {
+   if(length >= sizeof(struct NotReady) - SR_MAX_INFOSIZE) {
       /* ====== Get info string ========================================== */
       size_t i;
-      for(i = 0;i < (length - sizeof(struct NotReady));i++) {
+      for(i = 0;i < length - (sizeof(struct NotReady) - SR_MAX_INFOSIZE);i++) {
          if(i == SR_MAX_INFOSIZE) {
             break;
          }
@@ -265,9 +265,11 @@ static void handleNotReadyMessage(const int              sd,
    else {
       InfoString[0] = 0x00;
    }
-   newLogLine(stdout);
-   printf("Server %s is not ready yet => trying another one.\n", InfoString);
-   fflush(stdout);
+   if(!Quiet) {
+      newLogLine(stdout);
+      printf("Server %s is not ready yet => trying another one.\n", InfoString);
+      fflush(stdout);
+   }
 }
 
 
@@ -276,7 +278,7 @@ static unsigned int handleReadyMessage(const int           sd,
                                        const struct Ready* ready,
                                        const size_t        length)
 {
-   if(length < sizeof(struct Ready)) {
+   if(length < sizeof(struct Ready) - SR_MAX_INFOSIZE) {
       newLogLine(stdout);
       puts("Received invalid Ready message!");
       fflush(stdout);
@@ -285,7 +287,7 @@ static unsigned int handleReadyMessage(const int           sd,
 
    /* ====== Get info string ============================================= */
    size_t i;
-   for(i = 0;i < (length - sizeof(struct Ready));i++) {
+   for(i = 0;i < length - (sizeof(struct Ready) - SR_MAX_INFOSIZE);i++) {
       if(i == SR_MAX_INFOSIZE) {
          break;
       }
