@@ -1,4 +1,4 @@
-/* $Id: scriptingservice.cc 2480 2011-02-01 15:16:49Z dreibh $
+/* $Id: scriptingservice.cc 2595 2011-10-27 14:00:10Z dreibh $
  * --------------------------------------------------------------------------
  *
  *              //===//   //=====   //===//   //       //   //===//
@@ -147,17 +147,17 @@ void ScriptingServer::scriptingPrintParameters(const void* userData)
 // ###### Reject new session when server is fully loaded ####################
 void ScriptingServer::rejectNewSession(int sd)
 {
-   char           buffer[sizeof(NotReady) + SR_MAX_INFOSIZE];
+   char           buffer[sizeof(NotReady)];
    struct utsname systemInfo;
 
    if(uname(&systemInfo) != 0) {
       systemInfo.nodename[0] = 0x00;
    }
-
+   
    NotReady* notReady = (NotReady*)&buffer;
-   memset((char*)&notReady->Info, 0x00, SR_MAX_INFOSIZE);
-   snprintf((char*)&notReady->Info, SR_MAX_INFOSIZE, "%s", systemInfo.nodename);
-   const ssize_t notReadyLength = sizeof(NotReady) + strlen(notReady->Info);
+   memset((char*)&notReady->Info, 0x00, sizeof(notReady->Info));
+   snprintf((char*)&notReady->Info, sizeof(notReady->Info), "%s", systemInfo.nodename);
+   const ssize_t notReadyLength = sizeof(NotReady) + strlen(notReady->Info) - SR_MAX_INFOSIZE;
    notReady->Header.Type   = SPT_NOTREADY;
    notReady->Header.Flags  = 0x00;
    notReady->Header.Length = htons(notReadyLength);
@@ -172,30 +172,37 @@ void ScriptingServer::rejectNewSession(int sd)
 EventHandlingResult ScriptingServer::initializeSession()
 {
    // ====== Create directory and get file names ============================
-   safestrcpy((char*)&Directory, "/tmp/rspSS-XXXXXX", sizeof(Directory));
+   const char* tempDirectory = getenv("TMPDIR");
+   if(tempDirectory == NULL) {
+      safestrcpy((char*)&Directory, "/tmp", sizeof(Directory));
+   }
+   else {
+      safestrcpy((char*)&Directory, tempDirectory, sizeof(Directory));
+   }
+   safestrcat((char*)&Directory, "/rspSS-Session-XXXXXX", sizeof(Directory));
    if(mkdtemp((char*)&Directory) == NULL) {
       printTimeStamp(stdlog);
       fprintf(stdlog, "S%04d: Unable to generate temporary directory!\n",
-            RSerPoolSocketDescriptor);
+              RSerPoolSocketDescriptor);
       return(EHR_Abort);
    }
-   snprintf((char*)&EnvironmentName,  sizeof(EnvironmentName), "%s/%s",  Directory, ENVIRONMENT_NAME);
-   snprintf((char*)&InputName,  sizeof(InputName), "%s/%s",  Directory, INPUT_NAME);
+   snprintf((char*)&EnvironmentName, sizeof(EnvironmentName), "%s/%s", Directory, ENVIRONMENT_NAME);
+   snprintf((char*)&InputName,  sizeof(InputName),  "%s/%s", Directory, INPUT_NAME);
    snprintf((char*)&OutputName, sizeof(OutputName), "%s/%s", Directory, OUTPUT_NAME);
    snprintf((char*)&StatusName, sizeof(StatusName), "%s/%s", Directory, STATUS_NAME);
 
 
    // ====== Send Ready message =============================================
-   char           buffer[sizeof(Ready) + SR_MAX_INFOSIZE];
+   char           buffer[sizeof(Ready)];
    struct utsname systemInfo;
    if(uname(&systemInfo) != 0) {
       systemInfo.nodename[0] = 0x00;
    }
 
    Ready* ready = (Ready*)&buffer;
-   memset((char*)&ready->Info, 0x00, SR_MAX_INFOSIZE);
-   snprintf((char*)&ready->Info, SR_MAX_INFOSIZE, "%s", systemInfo.nodename);
-   const ssize_t readyLength = sizeof(Ready) + strlen(ready->Info);
+   memset((char*)&ready->Info, 0x00, sizeof(ready->Info));
+   snprintf((char*)&ready->Info, sizeof(ready->Info), "%s", systemInfo.nodename);
+   const ssize_t readyLength = sizeof(Ready) + strlen(ready->Info) - SR_MAX_INFOSIZE;
    ready->Header.Type   = SPT_READY;
    ready->Header.Flags  = 0x00;
    ready->Header.Length = htons(readyLength);
