@@ -1,4 +1,4 @@
-/* $Id: sessioncontrol.c 2409 2011-01-01 20:38:28Z dreibh $
+/* $Id: sessioncontrol.c 2598 2011-10-27 14:19:15Z dreibh $
  * --------------------------------------------------------------------------
  *
  *              //===//   //=====   //===//   //       //   //===//
@@ -477,7 +477,6 @@ void handleControlChannelMessage(struct RSerPoolSocket* rserpoolSocket,
                                  size_t                 bufferSize)
 {
    struct RSerPoolMessage* message;
-   unsigned int            type = 0;
    unsigned int            result;
 
    struct Session* session = findSession(rserpoolSocket, 0, assocID);
@@ -491,7 +490,6 @@ void handleControlChannelMessage(struct RSerPoolSocket* rserpoolSocket,
       result = rserpoolPacket2Message(buffer, NULL, 0, PPID_ASAP, bufferSize, bufferSize, &message);
       if(message != NULL) {
          if(result == RSPERR_OKAY) {
-            type = message->Type;
             switch(message->Type) {
                case AHT_COOKIE:
                   LOG_VERBOSE
@@ -549,7 +547,7 @@ bool handleControlChannelAndNotifications(struct RSerPoolSocket* rserpoolSocket)
    int      flags;
 
    /* ====== Check, if message on socket is notification or ASAP ========= */
-   flags   = MSG_PEEK;   /* Only peek to check of data is of right type! */
+   flags   = MSG_PEEK;   /* Only peek to check if data is of right type! */
    result  = recvfromplus(rserpoolSocket->Socket, (char*)&buffer, sizeof(buffer),
                           &flags, NULL, NULL, &ppid, NULL, NULL, 0);
    if( (result > 0) &&
