@@ -1,4 +1,4 @@
-/* $Id: tcplikeserver.cc 2520 2011-02-19 10:05:52Z dreibh $
+/* $Id: tcplikeserver.cc 2596 2011-10-27 14:08:44Z dreibh $
  * --------------------------------------------------------------------------
  *
  *              //===//   //=====   //===//   //       //   //===//
@@ -714,16 +714,13 @@ void TCPLikeServerList::remove(TCPLikeServer* thread)
 // ###### Get total load ####################################################
 double TCPLikeServerList::getTotalLoad()
 {
-   size_t             threads;
-   unsigned long long loadSum;
-
    lock();
-   threads = Threads;
-   loadSum = LoadSum;
+   const size_t             threads = Threads;
+   const unsigned long long loadSum = LoadSum;
    unlock();
 
    if(threads > 0) {
-      return(LoadSum / (double)PPV_MAX_LOAD);
+      return(loadSum / (double)PPV_MAX_LOAD);
    }
    return(0.0);
 }
