@@ -1,4 +1,4 @@
-/* $Id: udplikeserver.cc 2236 2009-10-13 07:15:31Z dreibh $
+/* $Id: udplikeserver.cc 2409 2011-01-01 20:38:28Z dreibh $
  * --------------------------------------------------------------------------
  *
  *              //===//   //=====   //===//   //       //   //===//
@@ -9,7 +9,7 @@
  *
  * ------------- An Efficient RSerPool Prototype Implementation -------------
  *
- * Copyright (C) 2002-2009 by Thomas Dreibholz
+ * Copyright (C) 2002-2011 by Thomas Dreibholz
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -197,7 +197,8 @@ void UDPLikeServer::poolElement(const char*          programTitle,
             // ====== Print program title =========================================
             if(!quiet) {
                puts(programTitle);
-               for(size_t i = 0;i < strlen(programTitle);i++) {
+               const size_t programTitleSize = strlen(programTitle);
+               for(size_t i = 0;i < programTitleSize;i++) {
                   printf("=");
                }
                const char* policyName = rsp_getpolicybytype(loadinfo->rli_policy);
@@ -310,10 +311,18 @@ void UDPLikeServer::poolElement(const char*          programTitle,
                            // ====== Check for problems ===========================
                            if((eventHandlingResult == EHR_Abort) ||
                               (eventHandlingResult == EHR_Shutdown)) {
+#ifdef SOLARIS
+                              rsp_sendmsg(RSerPoolSocketDescriptor,
+                                          NULL, 0,
+                                          ((eventHandlingResult == EHR_Abort) ? MSG_ABORT : MSG_EOF),
+                                          rinfo.rinfo_session, 0, 0, 0,
+                                          0, 0);
+#else
                               rsp_sendmsg(RSerPoolSocketDescriptor,
                                           NULL, 0, 0,
                                           rinfo.rinfo_session, 0, 0, 0,
                                           ((eventHandlingResult == EHR_Abort) ? SCTP_ABORT : SCTP_EOF), 0);
+#endif
                            }
                         }
                      }
